Thumbnails gallery
==================

.. nbgallery::
   notebooks/Fieldmaps
   notebooks/FirstProofofConcept
   notebooks/HTML_param_groups
   notebooks/JSON_PoC_read_write
   notebooks/Key_and_Param_Groups
   notebooks/keyparamgrouptest
   notebooks/metadata_image_param
   notebooks/PofC_Key_Values2
   notebooks/rename_files_work
   notebooks/workwithtestdata
